@@ -232,6 +232,7 @@ latexmk_emu = function(
   if (file.exists(idx <- aux_files['idx'])) {
     idx_engine = getOption('tinytex.makeindex', 'makeindex')
     install_cmd(idx_engine)
+    run_engine()  # run the engine one more time (cf rstudio/bookdown#1274)
     system2_quiet(idx_engine, c(getOption('tinytex.makeindex.args'), shQuote(idx)), error = {
       stop("Failed to build the index via ", idx_engine, call. = FALSE)
     })
@@ -581,6 +582,9 @@ regex_errors = function() {
     colorprofiles.sty = c(
       '.* Package pdfx Error: No color profile ([^ ]+).*'
     ),
+    `lua-uni-algos.lua` = c(
+      ".* module '(lua-uni-normalize)' not found:.*"
+    ),
     tikz = c(
       # when a required tikz library is missing
       '.* (tikzlibrary[^ ]+?[.]code[.]tex).*'
@@ -609,7 +613,8 @@ detect_files = function(text) {
     v = grep_sub(p, '\\1', x)
     if (length(v) == 0) return(v)
     if (p == r$tikz && length(grep('! Package tikz Error:', text)) == 0) return()
-    for (i in c('epstopdf', 'colorprofiles.sty')) {
+    # these are some known filenames
+    for (i in c('epstopdf', grep('[.]', names(r), value = TRUE))) {
       if (p %in% r[[i]]) return(i)
     }
     if (p == r$fd) v = tolower(v)  # LGRcmr.fd -> lgrcmr.fd
