@@ -27,15 +27,15 @@
 #' @references The \pkg{tlmgr} manual:
 #'   \url{https://www.tug.org/texlive/doc/tlmgr.html}
 #' @export
-#' @examples
+#' @examplesIf interactive()
 #' # search for a package that contains titling.sty
 #' tlmgr_search('titling.sty')
 #'
-#' #' to match titling.sty exactly, add a slash before the keyword, e.g.
-#' #' tlmgr_search('/titling.sty')
+#' # to match titling.sty exactly, add a slash before the keyword, e.g.
+#' tlmgr_search('/titling.sty')
 #'
-#' #' use a regular expression if you want to be more precise, e.g.
-#' #' tlmgr_search('/titling\\.sty$')
+#' # use a regular expression if you want to be more precise, e.g.
+#' tlmgr_search('/titling\\.sty$')
 #'
 #' # list all installed LaTeX packages
 #' tlmgr(c('info', '--list', '--only-installed', '--data', 'name'))
@@ -46,6 +46,9 @@ tlmgr = function(args = character(), usermode = FALSE, ..., .quiet = FALSE) {
   )
   if (usermode) args = c('--usermode', args)
   if (!.quiet) message(paste(c('tlmgr', args), collapse = ' '))
+  # use TeX Live's own binaries (e.g., curl): https://github.com/yihui/tinytex/issues/354
+  vars = xfun::set_envvar(c(TEXLIVE_PREFER_OWN = 1))
+  on.exit(xfun::set_envvar(vars), add = TRUE)
   system2('tlmgr', args, ...)
 }
 
@@ -168,6 +171,22 @@ tlmgr_remove = function(pkgs = character(), usermode = FALSE) {
   if (length(pkgs)) tlmgr(c('remove', pkgs), usermode)
 }
 
+#' @param raw Whether to return the raw output of the command \command{tlmgr
+#'   --version}, or a short version of the format \samp{TeX Live YEAR (TinyTeX)
+#'   with tlmgr DATE}.
+#' @rdname tlmgr
+#' @importFrom xfun raw_string
+#' @export
+tlmgr_version = function(raw = TRUE) {
+  vers = tlmgr('--version', stdout = TRUE, .quiet = TRUE)
+  if (!raw) {
+    year = xfun::grep_sub('^TeX Live.* version (\\d+).*$', '\\1', vers)[1]
+    tinytex = if (is_tinytex()) '(TinyTeX) ' else ''
+    date = xfun::grep_sub('^tlmgr revision \\d+ \\(([0-9-]+) .*$', '\\1', vers)[1]
+    vers = sprintf('TeX Live %s %swith tlmgr %s', year, tinytex, date)
+  }
+  xfun::raw_string(vers)
+}
 
 #' @param self Whether to update the TeX Live Manager itself.
 #' @param more_args A character vector of more arguments to be passed to the
